This is a sort of log to maintain all the code written during lab courses.

Install using:

    pip install delft_physics_lab

Currently it only contains the solutions to the exercises we got on the tests. To call the functions, just use:

    from delft_physics_lab.tests import test1
    test1.exercise1()

This code will run the solution to exercise 1 from test 1. 

Currently available are the solutions to:
  - test1:
      - exercise1
      - exercise2

  - test2:
    - exercise1
    - exercise2
    - exercise3
    
  - test3:
    - exercise1
    - exercise2
    - exercise3

If you want the code for the solution, just look for the source code in this repository.

Hopefully this repository will prove to be useful in the future, when we need to use python in the lab.
Until then it's just a fun log of what we've done.